%global version 2.1.0
%global rpmrelease 9
# betarelease is either 0 or something like beta1
%global betarelease beta5

%if "%{betarelease}" != "0"
%global progver %{version}-%{betarelease}
%else
%global progver %{version}
%endif

# systemd options
%global _has_systemd %(eval rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  %global _servicefile_postfix %{_has_systemd}.service
%else
  %global _servicefile_postfix init
%endif

Summary: An application level gateway for FTP
Name: ftpproxy
Version: %{version}
%if "%{betarelease}" != "0"
Release: 0.%{betarelease}_%{rpmrelease}%{?dist}
%else
Release: %{rpmrelease}%{?dist}
%endif
License: GPLv2+
Group: System Environment/Daemons
URL: http://www.ftpproxy.org/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
%if "%{betarelease}" != "0"
Source0: http://www.ftpproxy.org/download/beta/%{name}-%{version}-%{betarelease}.tgz
%else
Source0: http://www.ftpproxy.org/download/%{name}-%{version}.tgz
%endif
Source1: %{name}.%{_servicefile_postfix}
Source2: %{name}.sysconfig
Source3: %{name}.conf
Patch0: ftpproxy-2.1.0-beta5-nostrip.patch
Patch1: ftpproxy-2.1.0-beta5-detach.patch
Requires: exec-tools >= 1.4
Requires(pre): %{_sbindir}/groupadd, %{_sbindir}/useradd
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
FTP Proxy is an application level gateway for FTP. It sits between a
client and a server forwarding command and data streams supporting a
subset of the file transfer protocol as described in RFC 959.

Beside this basic function which makes the program useful on firewall
or masqueraders it offers fixing the FTP server (e.g. for connections
into a protected LAN) and proxy authentication.

%prep
%if "%{betarelease}" != "0"
%setup -q -n %{name}-%{version}-%{betarelease}
%else
%setup -q -n %{name}-%{version}
%endif
%patch0 -p1 -b .nostrip
%patch1 -p1 -b .detach
find samples/ -type f -exec %{__chmod} 0644 {} \;
%{__rm} -f samples/.*.conf.swp

%build
%{__make} clean
%{__make} -C src ftp.proxy CFLAGS='%{optflags} -DVERSION=\"%{progver}\" -DFTP_FILECOPY -DFACILITY_NAMES'

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -d %{buildroot}%{_bindir}
%{__install} -d %{buildroot}%{_mandir}/man1

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__install} -m 0644 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}.conf
%{__install} -m 0755 -p src/ftp.proxy %{buildroot}%{_bindir}/
%{__install} -m 0644 -p doc/ftp.proxy.1 %{buildroot}%{_mandir}/man1/

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%pre
getent group %{name} > /dev/null || %{_sbindir}/groupadd -r %{name} 2> /dev/null || :
getent passwd %{name} > /dev/null || \
  %{_sbindir}/useradd -g %{name} -s /sbin/nologin -r -c "FTP Proxy Server" -d / %{name} 2> /dev/null || :

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%systemd_postun_with_restart %{name}.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc HISTORY LICENSE doc/rfc* samples/
%if %{_has_systemd}
%{_unitdir}/%{name}.service
%else
%config %{_initrddir}/%{name}
%endif
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_bindir}/ftp.proxy
%{_mandir}/man1/ftp.proxy.1*

%changelog
* Fri Jan 07 2022 Simon Matter <simon.matter@invoca.ch> 2.1.0-0.beta5_9
- add support for EL9

* Wed Jan 13 2021 Simon Matter <simon.matter@invoca.ch> 2.1.0-0.beta5_8
- run as user ftpproxy

* Fri May 22 2015 Simon Matter <simon.matter@invoca.ch> 2.1.0-0.beta5_7
- add support for systemd

* Thu Aug 11 2011 Simon Matter <simon.matter@invoca.ch> 2.1.0-0.beta5_6
- cosmetic changes

* Thu Aug 11 2011 Simon Matter <simon.matter@invoca.ch> 2.1.0-0.beta5_5
- add more fixed to daemon mode

* Thu Aug 11 2011 Simon Matter <simon.matter@invoca.ch> 2.1.0-0.beta5_4
- improve detach patch

* Thu Aug 11 2011 Simon Matter <simon.matter@invoca.ch> 2.1.0-0.beta5_3
- add patch to properly detach from the parent in daemon mode
- improve init script

* Thu Aug 11 2011 Simon Matter <simon.matter@invoca.ch> 2.1.0-0.beta5_2
- improve init script

* Thu Aug 11 2011 Simon Matter <simon.matter@invoca.ch> 2.1.0-0.beta5_1
- initial package
